@@ -3,7 +3,7 @@ package Crypt::SSSS;
 use strict;
 use warnings;
 
-our $VERSION = 0.2;
+our $VERSION = 0.3;
 
 require Exporter;
 
@@ -221,7 +221,7 @@ Sergey Zasenko, C<undef@cpan.org>.
 
 =over 2
 
-Mohammad S Anwar (Manwar)
+=item Mohammad S Anwar (MANWAR)
 
 =back
 
